@@ -34,9 +34,10 @@ ComicEngine::ComicEngine(QObject *parent)
 QList<ComicProviderInfo> ComicEngine::loadProviders()
 {
     mProviders.clear();
-    auto comics = KPackage::PackageLoader::self()->listPackages(QStringLiteral("Plasma/Comic"));
+    const auto comics = KPackage::PackageLoader::self()->listKPackages(QStringLiteral("Plasma/Comic"));
     QList<ComicProviderInfo> providers;
-    for (auto comic : comics) {
+    for (auto comicPackage : comics) {
+        const KPluginMetaData comic = comicPackage.metadata();
         qCDebug(PLASMA_COMIC) << "ComicEngine::loadProviders()  service name=" << comic.name();
         ComicProviderInfo data;
         data.pluginId = comic.pluginId();
